@@ -3,6 +3,7 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Object;
+require WebService::Shippo::ObjectList;
 use Carp         ( 'croak' );
 use JSON::XS     ();
 use Scalar::Util ( 'blessed', 'reftype' );
@@ -28,21 +29,8 @@ sub new
     return $self;
 }
 
-sub rebless
 {
-    my ( $self, $new_class ) = @_;
-    return $self unless ref( $self );
-    my $class = $self->class;
-    $new_class = ref( $new_class ) || $new_class;
-    no strict 'refs';
-    push @{"$new_class\::ISA"}, $class
-        unless $new_class->isa( $class );
-    bless $self, $new_class;
-    return $self;
-}
-
-{
-    my $json = JSON::XS->new->utf8;
+    my $json = JSON::XS->new->utf8->convert_blessed->allow_blessed;;
 
     sub construct_from
     {
@@ -53,20 +41,12 @@ sub rebless
         if ( $ref_type eq 'HASH' ) {
             my $self = $invocant->new( $response->{object_id} );
             $self->refresh_from( $response );
-            # Rebless as WebService::Shippo::<Thing>List if the response is
-            # a list of things. Ensure that WebService::Shippo::<Thing>List
-            # is a WebService::Shippo::Object.
             if ( exists( $self->{count} ) && exists( $self->{results} ) ) {
-                my $class = $self->class;
+                my $item_class = $self->class;
                 for my $thing ( @{ $self->{results} } ) {
-                    # Correctly bless the members of the list
-                    bless $thing, $class;
+                    bless $thing, $item_class;
                 }
-                # Make $self a WebService::Shippo::ListObject
-                bless $self, 'WebService::Shippo::ListObject';
-                # Now make $self a WebService::Shippo::<Type>List, making
-                # that class a subclass of WebService::Shippo::ListObject.
-                $self->rebless( $class . 'List' );
+                bless $self, $self->list_class;
             }
             return $self;
         }
@@ -86,6 +66,18 @@ sub rebless
     }
 }
 
+{
+    my $value = 0;
+
+    sub PRETTY
+    {
+        my ( $class, $new_value ) = @_;
+        return $value unless @_ > 1;
+        $value = $new_value;
+        return $class;
+    }
+}
+
 sub refresh_from
 {
     my ( $self, $hash ) = @_;
@@ -94,39 +86,60 @@ sub refresh_from
 }
 
 {
-    my $json = JSON::XS->new->utf8->pretty->canonical->convert_blessed;
-
-    # Serializes the object to a JSON string
-    sub to_json
-    {
-        my ( $self ) = @_;
-        return $json->encode( $self );
-    }
+    my $json = JSON::XS->new->utf8->canonical->convert_blessed->allow_blessed;
 
+    # Note to non-Perl hackers:
+    # Not having to unpack "@_" array gives slight speed boost, since it
+    # is possible that we might be creating many JSON strings in rapid
+    # succession. That weird looking "$_[0]" in the "TO_JSON", "to_json",
+    # and "to_string" methods is the first element of the "@_" array, i.e.
+    # the first argument passed to the method (the object itself).
+    #
     # Required by JSON::XS because we use the convert_blessed encoding
     # modifier to allow blessed references (aka Perl object instances)
     # to be serialized. Returns a scalar value that can be serialized
     # as JSON (essentially an unblessed shallow copy of the original
     # object).
+    #
     sub TO_JSON
     {
-        my ( $self ) = @_;
-        return { %{$self} };
+        return { %{ $_[0] } };
     }
 
+    # Serializes the object to a JSON string.
+    sub to_json
+    {
+        $json->pretty
+            if PRETTY;
+        return $json->encode( $_[0] );
+    }
+
+    # Also, serializes the object to a JSON string. This method will be
+    # called whenever the object is treated as a string, courtesy of the
+    # overload at the top of this module.
     sub to_string
     {
-        my ( $self ) = @_;
-        return $json->encode( $self );
+        $json->pretty
+            if PRETTY;
+        return $json->encode( $_[0] );
     }
 }
 
+sub id
+{
+    my ( $self ) = @_;
+    return exists( $self->{object_id} ) ? $self->{object_id} : undef;
+}
+
+# Just in time creation of mutators for orphaned method calls, to facilitate
+# access to object attributes of the same name.
 sub AUTOLOAD
 {
     my ( $invocant, @args ) = @_;
     my $class = ref( $invocant ) || $invocant;
     ( my $method = $AUTOLOAD ) =~ s{^.*\::}{};
-    return if $method eq 'DESTROY';
+    return
+        if $method eq 'DESTROY';
     no strict 'refs';
     my $sym = "$class\::$method";
     *$sym = set_subname(
