@@ -6,11 +6,11 @@ package WebService::Shippo::Resource;
 require WebService::Shippo::Request;
 use Carp        ( 'croak' );
 use URI::Encode ( 'uri_encode' );
-use base ( 'WebService::Shippo::Object' );
-use constant DEFAULT_API_SCHEME    => 'https';
-use constant DEFAULT_API_HOST      => 'api.goshippo.com';
-use constant DEFAULT_API_PORT      => '443';
-use constant DEFAULT_API_BASE_PATH => 'v1';
+use base        ( 'WebService::Shippo::Object' );
+use constant DEFAULT_API_SCHEME  => 'https';
+use constant DEFAULT_API_HOST    => 'api.goshippo.com';
+use constant DEFAULT_API_PORT    => '443';
+use constant DEFAULT_API_VERSION => 'v1';
 
 {
     my $value = undef;
@@ -44,7 +44,8 @@ use constant DEFAULT_API_BASE_PATH => 'v1';
         my ( $class, $new_value ) = @_;
         return $value unless @_ > 1;
         $value = $new_value;
-        Shippo::Request->headers->{Authorization} = "ShippoToken $value";
+        Shippo::Request->headers->{Authorization} = "ShippoToken $value"
+            if $value;
         return $class;
     }
 }
@@ -59,11 +60,6 @@ use constant DEFAULT_API_BASE_PATH => 'v1';
         $value = ( $new_value || DEFAULT_API_SCHEME );
         return $class;
     }
-
-    BEGIN {
-        no warnings 'once';
-        *api_protocol = *api_scheme;
-    }
 }
 
 {
@@ -91,48 +87,67 @@ use constant DEFAULT_API_BASE_PATH => 'v1';
 }
 
 {
-    my $value = DEFAULT_API_BASE_PATH;
+    my $value = DEFAULT_API_VERSION;
 
     sub api_base_path
     {
         my ( $class, $new_value ) = @_;
         return $value unless @_ > 1;
-        ( $value = $new_value || DEFAULT_API_BASE_PATH ) =~ s{(^\/*|\/*$)}{};
+        ( $value = $new_value || DEFAULT_API_VERSION ) =~ s{(^\/*|\/*$)}{};
         return $class;
     }
 }
 
+{
+    my $value = undef;
+
+    sub api_endpoint
+    {
+        my ( $class, $new_value ) = @_;
+        unless ( @_ > 1 ) {
+            unless ( $value ) {
+                my $scheme = api_scheme();
+                my $port   = api_port();
+                my $path   = api_base_path;
+                $value = $scheme . '://' . api_host();
+                $value .= ':' . $port
+                    unless $port && $port eq '443' && $scheme eq 'https';
+                $value .= '/';
+                $value .= $path . '/'
+                    if $path;
+            }
+            return $value;
+        }
+        ( $value = $new_value || DEFAULT_API_VERSION ) =~ s{(^\/*|\/*$)}{};
+        return $class;
+    }
+}
+
+sub url
+{
+    my ( $class, $id ) = @_;
+    my $resource = $class->api_resource;
+    my $url      = $class->api_endpoint;
+    $url .= $resource . '/'
+        if $resource;
+    $url .= uri_encode( $id ) . '/'
+        if @_ > 1 && $id;
+    return $url;
+}
+
 sub api_resource
 {
     croak 'Method not implemented in abstract base class';
 }
 
-sub url
-{
-    my ( $class, $id ) = @_;
-    my $scheme   = $class->api_scheme;
-    my $port     = $class->api_port;
-    my $path     = $class->api_base_path;
-    my $resource = $class->api_resource;
-    my $url      = $scheme . '://';
-    $url .= $class->api_host;
-    $url .= ':' . $port
-        unless $port && $port eq '443' && $scheme eq 'https';
-    $url .= '/' . $path
-        if $path;
-    $url .= '/' . $resource
-        if $resource;
-    $url .= '/' . uri_encode( $id )
-        if @_ > 1 && $id;
-    $url .= '/';
-    return $url;
-}
-
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
     *Shippo::Resource:: = *WebService::Shippo::Resource::;
+    # Other aliases
+    *class_url    = *url;
+    *api_protocol = *api_scheme;
 }
 
 1;
