@@ -11,11 +11,16 @@ use base ( 'WebService::Shippo::Creator',
 
 sub api_resource {'transactions'}
 
+package    # Hide from PAUSE
+    WebService::Shippo::TransactionList;
+use base ( 'WebService::Shippo::ObjectList' );
+
 BEGIN {
     no warnings 'once';
     # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
     # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Transaction:: = *WebService::Shippo::Transaction::;
+    *Shippo::Transaction::     = *WebService::Shippo::Transaction::;
+    *Shippo::TransactionList:: = *WebService::Shippo::TransactionList::;
 }
 
 1;
